diarrhouea is a simple VTE-based terminal emulator written in Python

## Dependencies

* Python 3
* PyGObject 
* GTK+ 3
* VTE

## Where's the fucking manual?

At the time, only `--help` is available

## How to configure

Just put your command line arguments into `~/.diarrhouearc` and you'll be fine
